using AutobusApi.Application.Common.Models;
using AutobusApi.Application.Employees.Commands.CreateEmployee;
using AutobusApi.Application.Employees.Commands.DeleteEmployee;
using AutobusApi.Application.Employees.Commands.UpdateEmployee;
using AutobusApi.Application.Employees.Queries;
using AutobusApi.Application.Employees.Queries.GetEmployeesWithPagination;
using AutobusApi.Application.Employees.Queries.GetEmployee;
using Microsoft.AspNetCore.Mvc;

namespace AutobusApi.Api.Controllers;

[Route("employees")]
public class EmployeeController : BaseController
{
    [HttpPost]
    public async Task<int> Create([FromBody] CreateEmployeeCommand command, CancellationToken cancellationToken)
    {
        return await Mediator.Send(command, cancellationToken);
    }

    [HttpGet]
    public async Task<PaginatedList<EmployeeDto>> GetPage([FromQuery] GetEmployeesWithPaginationQuery query, CancellationToken cancellationToken)
    {
        return await Mediator.Send(query, cancellationToken);
    }

    [HttpGet("{id}")]
    public async Task<EmployeeDto> Get(int id, /* [FromQuery] GetEmployeeQuery query, */ CancellationToken cancellationToken)
    {
        var query = new GetEmployeeQuery() { Id = id };
        return await Mediator.Send(query, cancellationToken);
    }

    [HttpPut]
    public async Task Update([FromBody] UpdateEmployeeCommand command, CancellationToken cancellationToken)
    {
        await Mediator.Send(command, cancellationToken);
    }

    [HttpDelete("{id}")]
    public async Task Delete(int id, /* [FromBody] DeleteEmployeeCommand command, */ CancellationToken cancellationToken)
    {
        var command = new DeleteEmployeeCommand() { Id = id };
        await Mediator.Send(command, cancellationToken);
    }
}
