using AutobusApi.Application.Common.Exceptions;
using AutobusApi.Application.Common.Interfaces;
using AutoMapper;
using MediatR;
using Microsoft.EntityFrameworkCore;

namespace AutobusApi.Application.Addresses.Queries.GetAddress;

public class GetAddressQueryHandler : IRequestHandler<GetAddressQuery, AddressDto>
{
    private readonly IApplicationDbContext _dbContext;
    private readonly IMapper _mapper;

    public GetAddressQueryHandler(
        IApplicationDbContext dbContext,
        IMapper mapper)
    {
        _dbContext = dbContext;
        _mapper = mapper;
    }

    public async Task<AddressDto> Handle(
        GetAddressQuery request,
        CancellationToken cancellationToken)
    {
        var address = await _dbContext.Addresses
            .SingleOrDefaultAsync(c => c.Id == request.Id);

        if (address == null)
        {
            throw new NotFoundException();
        }

        return _mapper.Map<AddressDto>(address);
    }
}
