using AutobusApi.Application.Common.Interfaces;
using AutobusApi.Application.Common.Mappings;
using AutobusApi.Application.Common.Models;
using AutoMapper;
using AutoMapper.QueryableExtensions;
using MediatR;

namespace AutobusApi.Application.Buses.Queries.GetBusesWithPagination;

public class GetBusesWithPaginationQueryHandler : IRequestHandler<GetBusesWithPaginationQuery, PaginatedList<BusDto>>
{
    private readonly IApplicationDbContext _dbContext;
    private readonly IMapper _mapper;

    public GetBusesWithPaginationQueryHandler(
        IApplicationDbContext dbContext,
        IMapper mapper)
    {
        _dbContext = dbContext;
        _mapper = mapper;
    }

    public async Task<PaginatedList<BusDto>> Handle(
        GetBusesWithPaginationQuery request,
        CancellationToken cancellationToken)
    {
        return await _dbContext.Buses
            .ProjectTo<BusDto>(_mapper.ConfigurationProvider)
            .ApplySort(request.Sort)
            .PaginatedListAsync(request.PageNumber, request.PageSize);
    }
}
