using AutobusApi.Application.Common.Interfaces;
using AutobusApi.Application.Common.Mappings;
using AutobusApi.Application.Common.Models;
using AutoMapper;
using AutoMapper.QueryableExtensions;
using MediatR;

namespace AutobusApi.Application.Regions.Queries.GetRegionsWithPagination;

public class GetRegionsWithPaginationQueryHandler : IRequestHandler<GetRegionsWithPaginationQuery, PaginatedList<RegionDto>>
{
    private readonly IApplicationDbContext _dbContext;
    private readonly IMapper _mapper;

    public GetRegionsWithPaginationQueryHandler(
        IApplicationDbContext dbContext,
        IMapper mapper)
    {
        _dbContext = dbContext;
        _mapper = mapper;
    }

    public async Task<PaginatedList<RegionDto>> Handle(
        GetRegionsWithPaginationQuery request,
        CancellationToken cancellationToken)
    {
        return await _dbContext.Regions
            .ProjectTo<RegionDto>(_mapper.ConfigurationProvider)
            .ApplySort(request.Sort)
            .PaginatedListAsync(request.PageNumber, request.PageSize);
    }
}
