using AutobusApi.Application.Common.Exceptions;
using AutobusApi.Application.Common.Interfaces;
using MediatR;
using Microsoft.EntityFrameworkCore;

namespace AutobusApi.Application.TicketGroups.Commands.DeleteTicketGroup;

public class DeleteTicketGroupCommandHandler : IRequestHandler<DeleteTicketGroupCommand>
{
    private readonly IApplicationDbContext _dbContext;

    public DeleteTicketGroupCommandHandler(IApplicationDbContext dbContext)
    {
        _dbContext = dbContext;
    }

    public async Task Handle(
        DeleteTicketGroupCommand request,
        CancellationToken cancellationToken)
    {
        var ticketGroup = await _dbContext.TicketGroups
            .SingleOrDefaultAsync(c => c.Id == request.Id, cancellationToken);

        if (ticketGroup == null)
        {
            throw new NotFoundException();
        }

        _dbContext.TicketGroups.Remove(ticketGroup);

        await _dbContext.SaveChangesAsync(cancellationToken);
    }
}
