using AutobusApi.Application.Common.Interfaces;
using AutobusApi.Application.Common.Mappings;
using AutobusApi.Application.Common.Models;
using AutoMapper;
using AutoMapper.QueryableExtensions;
using MediatR;

namespace AutobusApi.Application.TicketGroups.Queries.GetTicketGroupsWithPagination;

public class GetTicketGroupsWithPaginationQueryHandler : IRequestHandler<GetTicketGroupsWithPaginationQuery, PaginatedList<TicketGroupDto>>
{
    private readonly IApplicationDbContext _dbContext;
    private readonly IMapper _mapper;

    public GetTicketGroupsWithPaginationQueryHandler(
        IApplicationDbContext dbContext,
        IMapper mapper)
    {
        _dbContext = dbContext;
        _mapper = mapper;
    }

    public async Task<PaginatedList<TicketGroupDto>> Handle(
        GetTicketGroupsWithPaginationQuery request,
        CancellationToken cancellationToken)
    {
        return await _dbContext.TicketGroups
            .ProjectTo<TicketGroupDto>(_mapper.ConfigurationProvider)
            .ApplySort(request.Sort)
            .PaginatedListAsync(request.PageNumber, request.PageSize);
    }
}
